@@ -2,11 +2,11 @@ int <- function(s)
 {
   for(i in 1:length(s))
   {
-    dt <- s[[i]]$delta
-    x <- s[[i]]$x
+    dt <- s[[i]]$dt
+    x <- s[[i]]$amp
     A <- dt * x
     int <- cumsum(A)
-    s[[i]]$x <- int
+    s[[i]]$amp <- int
   }
   return(s)
 }
@@ -15,10 +15,10 @@ dif <- function(s)
 {
   for(i in 1:length(s))
   {
-    x <- s[[i]]$x
-    dt <- s[[i]]$delta
-    s[[i]]$x <- diff(x)/dt
-    s[[i]]$npts <- s[[i]]$npts - 1
+    x <- s[[i]]$amp
+    dt <- s[[i]]$dt
+    s[[i]]$amp <- diff(x)/dt
+    s[[i]]$N <- s[[i]]$N - 1
     s[[i]]$b <- s[[i]]$b + 0.5 * dt
   }
   return(s)
